require 'studio_game/game'
require 'studio_game/player'
module StudioGame
  describe Game do
    let(:game) { Game.new('Knuckeheads') }
    let(:initial_health) { 100 }
    let(:player_a) { Player.new('Ramón', initial_health) }
    let(:player_b) { Player.new('Jose', initial_health) }
    let(:rounds) { 2 }

    before do
      $stdout = StringIO.new
      game.add_player(player_a)
    end

    it 'w00ts the player if a high number is rolled' do
      allow_any_instance_of(Die).to receive(:roll).and_return(5)
      game.play(rounds)
      expect(player_a.health).to be(initial_health + 15 * rounds)
    end

    it 'does nothing to players health with medium number' do
      allow_any_instance_of(Die).to receive(:roll).and_return(3)
      game.play(rounds)
      expect(player_a.health).to eq(initial_health)
    end

    it 'blams the player if a low number is rolled' do
      allow_any_instance_of(Die).to receive(:roll).and_return(1)
      game.play(rounds)
      expect(player_a.health).to eq(initial_health - 10 * rounds)
    end

    it 'prints players stats' do
      allow_any_instance_of(Die).to receive(:roll).and_return(1)
      player_a.found_treasure(Treasure.new(:crowbar, 400))
      expect(game.print_stats[0].class).to eq(player_a.class)
    end

    it 'computes total points as the sum of all player points' do
      game.add_player(player_b)

      player_a.found_treasure(Treasure.new(:hammer, 50))
      player_a.found_treasure(Treasure.new(:hammer, 50))
      player_b.found_treasure(Treasure.new(:crowbar, 400))

      expect(game.total_points).to eq(500)
    end
  end
end
